Test Radio Button Events
open | ../tests/html/test_form_events.html |
verifyValue | theRadio1 | off
verifyValue | theRadio2 | off
verifyValue | eventlog |
click | theRadio1 |
verifyValue | theRadio1 | on
verifyValue | theRadio2 | off
verifyValue | eventlog | {focus(theRadio1)} *
verifyValue | eventlog | *{click(theRadio1)}*
verifyValue | eventlog | *{change(theRadio1)}*
type | eventlog |
click | theRadio2 |
verifyValue | theRadio1 | off
verifyValue | theRadio2 | on
verifyValue | eventlog | {focus(theRadio2)} *
verifyValue | eventlog | *{click(theRadio2)}*
verifyValue | eventlog | *{change(theRadio2)}*
type | eventlog |
click | theRadio2 |
verifyValue | theRadio1 | off
verifyValue | theRadio2 | on
verifyValue | eventlog | {focus(theRadio2)} {click(theRadio2)}